
.. only:: html

    .. include:: ../README.rst

    Content
    -------

.. only:: latex

    Intro
    =====
    This document is automatically created by `sphinx <https://www.sphinx-doc.org/en/master/index.html>`_, the Python documentation generator.
    It is synced with the online package documentation that is hosted at `Read the Docs <https://econpizza.readthedocs.io>`_.


.. toctree::
   :maxdepth: 2

   readme
   quickstart
   tutorial.ipynb
   method.ipynb
   modules
